#!/bin/bash

# UT99 Linux Setup script by Quasi^ aka ~V~
# Install script for those that have installed UT via the Demo + 436
# patch method.
# Includes a cache convertor script (ut99cache.sh).

# Whether UT will run or not is NOT guaranteed!

# Copyright 2014  Quasi^ aka ~V~ <dave@unrealize.co.uk>
# All rights reserved.
#
# Redistribution and use of this script, with or without modification, is
# permitted provided that the following conditions are met:
#
# 1. Redistributions of this script must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
#
# THIS SOFTWARE IS PROVIDED BY THE AUTHOR ''AS IS'' AND ANY EXPRESS OR IMPLIED
# WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
# MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
# EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
# SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
# PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
# OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
# WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
# OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
# ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.


# Edit the 3 paths below if they are not correct

# Where the demo is installed:
DEMO_PATH=$HOME/.wine/drive_c/UnrealTournament

# Where to place the link to start UT. Should be in your $PATH:
LINK_PATH=$HOME/bin

# Where to install the game files. Leave commented out to keep it in
# ~/.wine/drive_c/UnrealTournament or whatever you set for DEMO_PATH.
UT_PATH=$HOME/ut99

# No need to edit anything below this line.

VERSION=0.1
CWD=$(pwd)
blue='\e[01;34m'
green='\e[01;32m'
red='\e[01;31m'
normal='\e[m\017'

set -e 

function copy_files()
{
    echo -e $normal

    if [ "$UT_PATH" = "DEMO_PATH" ]; then
        echo -e "${red}ERROR: Your UT_PATH must not be the same as DEMO_PATH."
        echo -e $normal
        exit 1
    fi

    mkdir -p $UT_PATH
    (
        cd $UT_PATH
        mkdir -p System Maps Textures Music Sounds Web Help Logs
        chmod -R +rw *
    )

    echo -e "${blue}Copying Files...$normal"

    cp -vr $DEMO_PATH/System/* $UT_PATH/System/.
    cp -v $DEMO_PATH/Maps/* $UT_PATH/Maps/.
    cp -v $DEMO_PATH/Music/* $UT_PATH/Music/.
    cp -v $DEMO_PATH/Textures/* $UT_PATH/Textures/.
    cp -v $DEMO_PATH/Sounds/* $UT_PATH/Sounds/.
    cp -vr $DEMO_PATH/Web/* $UT_PATH/Web/.
    cp -v $DEMO_PATH/Help/* $UT_PATH/Help/.
    cp -v README* $UT_PATH/Help/.
}

copy_linux_files()
{
    cd $GAME_PATH || exit 1

    tar xvf $CWD/data.tar.gz
    tar xvf $CWD/Credits.tar.gz
    tar xvf $CWD/OpenGL.ini.tar.gz
    cp -v $CWD/bin/x86/* .
    cp -v $CWD/ut99cache.sh .
    sed -i "8iUT_DATA_PATH=$GAME_PATH\/System" ut
    sed -i "9i$GAME_PATH\/ut99cache.sh" ut
    cat System/UnrealTournament.ini.PATCH > System/UnrealTournament.ini
    rm -f System/UnrealTournament.ini.PATCH
    sed -i 's%GameRenderDevice=SDLGLDrv.SDLGLRenderDevice%GameRenderDevice=OpenGLDrv.OpenGLRenderDevice%' System/UnrealTournament.ini
    chmod -R +rw *
}

function make_links()
{
    rm -f $LINK_PATH/{ut,ucc}
    ln -s $GAME_PATH/ut $LINK_PATH/ut
    ln -s $GAME_PATH/ucc $LINK_PATH/ucc
    
    echo -e "${blue}Created Links in $LINK_PATH$normal"
}

function add_desktop()
{
    mkdir -p $HOME/.local/share/icons/hicolor/48x48 
    cp $CWD/icon.xpm $HOME/.local/share/icons/hicolor/48x48/ut.xpm

    mkdir -p $HOME/.local/share/applications
    cp $CWD/ut.desktop $HOME/.local/share/applications/.

    if [ -x /usr/bin/update-desktop-database ]; then
      /usr/bin/update-desktop-database -q $HOME/.local/share/applications >/dev/null 2>&1
    fi

    if [ -e $HOME/.local/share/icons/hicolor/icon-theme.cache ]; then
      if [ -x /usr/bin/gtk-update-icon-cache ]; then
        /usr/bin/gtk-update-icon-cache $HOME/.local/share/icons/hicolor >/dev/null 2>&1
      fi
    fi

    echo -e "${blue}Added desktop and icon files$normal"
}

echo -e "${green}UT99 Linux Installer Script version $VERSION by Quasi^ aka ~V~$normal"
echo -e "Using Demo installed in ${blue}$DEMO_PATH$normal"
echo -e "Using ${blue}$LINK_PATH$normal for UT startup script"

if [ -n "$UT_PATH" ]; then
    echo -e "Installing to ${blue}$UT_PATH$normal"
fi

echo "Before running this script you should edit the paths"
echo "at the top of this script and also the utdir path in ut99cache.sh"

echo -en "${green}Press Enter To Start Install$normal"
read

if [ -z "$UT_PATH" ]; then
    GAME_PATH=$DEMO_PATH
else
    GAME_PATH=$UT_PATH
fi

if [ -n "$UT_PATH" ]; then
    copy_files
fi

copy_linux_files
make_links
add_desktop

echo -e "${green}UT 436 for Linux Installed.$normal"
echo "Now type 'ut'."

